@@ -1,15 +1,15 @@
 import logging
 from collections import defaultdict
 
-from django.conf import settings
 from django.contrib.admin import site
 from django.contrib.admin.options import InlineModelAdmin
 from django.contrib.admin.utils import flatten_fieldsets
-from django.contrib.contenttypes.admin import GenericInlineModelAdmin
+from django.contrib.auth.admin import UserAdmin
 from django.db import models
 from django.db.models.fields.reverse_related import ForeignObjectRel
 from django.forms.models import _get_foreign_key
 
+from .common import settings
 from .orm_fields import (
     _AGGREGATES,
     _FUNC_MAP,
@@ -56,7 +56,12 @@ def _get_all_admin_fields(request):
     request.data_browser = {"calculated_fields": set()}
 
     def from_fieldsets(admin, all_):
-        obj = admin.model()  # we want the admin change field sets, not the add ones
+        auth_user_compat = settings.DATA_BROWSER_AUTH_USER_COMPAT
+        if auth_user_compat and isinstance(admin, UserAdmin):
+            obj = admin.model()  # we want the admin change field sets, not the add ones
+        else:
+            obj = None
+
         for f in flatten_fieldsets(admin.get_fieldsets(request, obj)):
             # skip calculated fields on inlines
             if not isinstance(admin, InlineModelAdmin) or hasattr(admin.model, f):
@@ -81,13 +86,15 @@ def _get_all_admin_fields(request):
 
             # check the inlines, these are already filtered for access
             for inline in model_admin.get_inline_instances(request):
-                if not isinstance(inline, GenericInlineModelAdmin):  # pragma: no branch
+                try:
+                    fk_field = _get_foreign_key(model, inline.model, inline.fk_name)
+                except Exception:
+                    pass
+                else:
                     if inline.model not in model_admins:  # pragma: no branch
                         model_admins[inline.model] = inline
                     all_admin_fields[inline.model].update(from_fieldsets(inline, False))
-                    all_admin_fields[inline.model].add(
-                        _get_foreign_key(model, inline.model, inline.fk_name).name
-                    )
+                    all_admin_fields[inline.model].add(fk_field.name)
 
     # we always have id and never pk
     for fields in all_admin_fields.values():
@@ -211,6 +218,7 @@ def _cols_sub_query(bound_query):
         bound_query.model_name,
         bound_query.col_fields + row_fields,
         bound_query.valid_filters,
+        bound_query.limit,
     )
 
 
@@ -220,6 +228,7 @@ def _rows_sub_query(bound_query):
         bound_query.model_name,
         bound_query.row_fields + col_fields,
         bound_query.valid_filters,
+        bound_query.limit,
     )
 
 
@@ -241,11 +250,21 @@ def _get_results(request, bound_query, orm_models):
         if filter_.orm_bound_field.filter_:
             qs = _filter(qs, filter_, filter_.orm_bound_field.queryset_path)
 
+    # nothing to group on, early out with an aggregate
+    if not any(f.group_by for f in bound_query.bound_fields):
+        return [
+            qs.aggregate(
+                **dict(
+                    field.aggregate_clause
+                    for field in bound_query.bound_fields + bound_query.bound_filters
+                    if field.aggregate_clause
+                )
+            )
+        ]
+
     # group by
     qs = qs.values(
-        *[field.queryset_path for field in bound_query.bound_fields if field.group_by],
-        # .values() is interpreted as all values, _ddb_dummy ensures there's always at least one
-        _ddb_dummy=models.Value(1, output_field=models.IntegerField()),
+        *[field.queryset_path for field in bound_query.bound_fields if field.group_by]
     ).distinct()
 
     # aggregates
@@ -258,10 +277,9 @@ def _get_results(request, bound_query, orm_models):
     )
 
     # having, aka filter aggregate fields
-    if any(f.group_by for f in bound_query.bound_fields):  # no group by -> no having
-        for filter_ in bound_query.valid_filters:
-            if filter_.orm_bound_field.having:
-                qs = _filter(qs, filter_, filter_.orm_bound_field.queryset_path)
+    for filter_ in bound_query.valid_filters:
+        if filter_.orm_bound_field.having:
+            qs = _filter(qs, filter_, filter_.orm_bound_field.queryset_path)
 
     # sort
     sort_fields = []
@@ -272,7 +290,7 @@ def _get_results(request, bound_query, orm_models):
             sort_fields.append(f"-{field.orm_bound_field.queryset_path}")
     qs = qs.order_by(*sort_fields)
 
-    return list(qs)
+    return list(qs[: bound_query.limit])
 
 
 def get_results(request, bound_query, orm_models):
@@ -311,15 +329,18 @@ def get_results(request, bound_query, orm_models):
     def format_table(fields, data):
         results = []
         for row in data:
-            res_row = {}
-            for field in fields:
-                value = row[field.path_str]
-                if field.model_name:
-                    admin = orm_models[field.model_name].admin
-                    obj = cache[field.model_name].get(value)
-                    value = obj, admin
-                res_row[field.path_str] = field.format(value)
-            results.append(res_row)
+            if row:
+                res_row = {}
+                for field in fields:
+                    value = row[field.path_str]
+                    if field.model_name:
+                        admin = orm_models[field.model_name].admin
+                        obj = cache[field.model_name].get(value)
+                        value = obj, admin
+                    res_row[field.path_str] = field.format(value)
+                results.append(res_row)
+            else:
+                results.append(row)
         return results
 
     def get_fields(row, fields):
@@ -340,11 +361,10 @@ def get_results(request, bound_query, orm_models):
         data[row_key][col_key] = dict(get_fields(row, bound_query.bound_data_fields))
 
     body = []
-    blank = {field.path_str: None for field in bound_query.bound_data_fields}
     for col_key in col_keys:
         table = []
         for row_key in row_keys:
-            table.append(data[row_key].get(col_key, blank))
+            table.append(data[row_key].get(col_key, None))
         body.append(format_table(bound_query.bound_data_fields, table))
 
     return {
@@ -355,4 +375,5 @@ def get_results(request, bound_query, orm_models):
             bound_query.bound_col_fields, [dict(col) for col in col_keys]
         ),
         "body": body,
+        "length": len(res),
     }
