@@ -4,6 +4,7 @@ from typing import Sequence, Tuple
 from django.contrib.admin.options import BaseModelAdmin
 from django.db import models
 from django.db.models import functions
+from django.db.models.functions import Cast
 from django.urls import reverse
 
 from .query import (
@@ -23,17 +24,18 @@ _OPEN_IN_ADMIN = "admin"
 
 
 _AGG_MAP = {
-    "average": models.Avg,
+    "average": lambda x: models.Avg(Cast(x, output_field=models.IntegerField())),
     "count": lambda x: models.Count(x, distinct=True),
     "max": models.Max,
     "min": models.Min,
     "std_dev": models.StdDev,
-    "sum": models.Sum,
+    "sum": lambda x: models.Sum(Cast(x, output_field=models.IntegerField())),
     "variance": models.Variance,
 }
 
 
 _AGGREGATES = {
+    # NTS beware that Sum(type) -> type
     StringType: ["count"],
     NumberType: ["average", "count", "max", "min", "std_dev", "sum", "variance"],
     DateTimeType: ["count"],  # average, min and max might be nice here but sqlite
