@@ -6,15 +6,15 @@ import sys
 
 import django.contrib.admin.views.decorators as admin_decorators
 from django import http
-from django.conf import settings
 from django.shortcuts import get_object_or_404
 from django.template import engines, loader
 from django.template.response import TemplateResponse
 from django.urls import reverse
 from django.utils import timezone
-from django.views.decorators.csrf import csrf_exempt
+from django.views.decorators import csrf
 
 from . import version
+from .common import HttpResponse, JsonResponse, can_make_public, settings
 from .models import View
 from .orm import _OPEN_IN_ADMIN, get_models, get_results
 from .query import TYPES, BoundQuery, Query
@@ -45,7 +45,7 @@ def _get_query_data(bound_query):
             for field in bound_query.fields
         ],
         "model": bound_query.model_name,
-        "version": version,
+        "limit": str(bound_query.limit),
     }
 
 
@@ -69,7 +69,8 @@ def _get_model_fields(orm_model):
     return {"fields": all_fields, "sortedFields": sort_model_fields(all_fields)}
 
 
-def _get_config(user, orm_models):
+def _get_config(request):
+    orm_models = get_models(request)
     types = {
         name: {
             "lookups": {n: {"type": t} for n, t in type_.lookups.items()},
@@ -85,75 +86,45 @@ def _get_config(user, orm_models):
         for model_name, orm_model in orm_models.items()
     }
 
-    saved_views = [
-        {
-            "name": view.name,
-            "public": view.public,
-            "model": view.model_name,
-            "description": view.description,
-            "query": _get_query_data(BoundQuery.bind(view.get_query(), orm_models)),
-        }
-        for view in View.objects.filter(owner=user).order_by("name")
-    ]
-
-    admin_url = None
-    if "data_browser.View" in orm_models:
-        admin_url = reverse(f"admin:{View._meta.db_table}_add")
-
     return {
         "baseUrl": reverse("data_browser:home"),
-        "adminUrl": admin_url,
         "types": types,
         "allModelFields": all_model_fields,
         "sortedModels": sorted(
             name for name, model in orm_models.items() if model.root
         ),
-        "version": version,
-        "savedViews": saved_views,
-    }
-
-
-def _get_context(request, model_name, fields):
-    query = Query.from_request(model_name, fields, request.GET)
-    orm_models = get_models(request)
-    if query.model_name and query.model_name not in orm_models:
-        raise http.Http404(f"{query.model_name} does not exist")
-    bound_query = BoundQuery.bind(query, orm_models)
-    return {
-        "config": _get_config(request.user, orm_models),
-        "initialState": {
-            "results": [],
-            "cols": [],
-            "rows": [],
-            **_get_query_data(bound_query),
-        },
-        "sentryDsn": getattr(settings, "DATA_BROWSER_FE_DSN", None),
+        "canMakePublic": can_make_public(request.user),
+        "sentryDsn": settings.DATA_BROWSER_FE_DSN,
+        "defaultRowLimit": settings.DATA_BROWSER_DEFAULT_ROW_LIMIT,
     }
 
 
 @admin_decorators.staff_member_required
-def query_ctx(request, *, model_name, fields=""):
-    ctx = _get_context(request, model_name, fields)
-    return http.JsonResponse(ctx)
+def query_ctx(request, *, model_name="", fields=""):
+    config = _get_config(request)
+    return JsonResponse(config)
 
 
+@csrf.ensure_csrf_cookie
 @admin_decorators.staff_member_required
 def query_html(request, *, model_name="", fields=""):
-    ctx = _get_context(request, model_name, fields)
-    ctx = json.dumps(ctx)
-    ctx = ctx.replace("<", "\\u003C").replace(">", "\\u003E").replace("&", "\\u0026")
+    config = _get_config(request)
+    config = json.dumps(config)
+    config = (
+        config.replace("<", "\\u003C").replace(">", "\\u003E").replace("&", "\\u0026")
+    )
 
-    if getattr(settings, "DATA_BROWSER_DEV", False):  # pragma: no cover
+    if settings.DATA_BROWSER_DEV:  # pragma: no cover
         try:
             response = _get_from_js_dev_server(request)
         except Exception as e:
-            return http.HttpResponse(f"Error loading from JS dev server.<br><br>{e}")
+            return HttpResponse(f"Error loading from JS dev server.<br><br>{e}")
 
         template = engines["django"].from_string(response.text)
     else:
         template = loader.get_template("data_browser/index.html")
 
-    return TemplateResponse(request, template, {"ctx": ctx})
+    return TemplateResponse(request, template, {"config": config, "version": version})
 
 
 @admin_decorators.staff_member_required
@@ -168,8 +139,8 @@ def view(request, pk, media):
         # some of these are checked by the admin but this is a good time to be paranoid
         view.owner.is_active
         and view.owner.is_staff
-        and view.owner.has_perm("data_browser.make_view_public")
-        and getattr(settings, "DATA_BROWSER_ALLOW_PUBLIC", False)
+        and can_make_public(view.owner)
+        and settings.DATA_BROWSER_ALLOW_PUBLIC
     ):
         request.user = view.owner  # public views are run as the person who owns them
         query = view.get_query()
@@ -198,7 +169,8 @@ def format_table(fields, table, spacing=0):
     return concat(
         [[" ".join(f.pretty_path) for f in fields]],
         *[
-            [[row[f.path_str] for f in fields]] + [pad(len(fields))] * spacing
+            [[(row[f.path_str] if row else "") for f in fields]]
+            + [pad(len(fields))] * spacing
             for row in table
         ],
     )
@@ -213,9 +185,9 @@ def _data_response(request, query, media, meta):
     if query.model_name not in orm_models:
         raise http.Http404(f"{query.model_name} does not exist")
     bound_query = BoundQuery.bind(query, orm_models)
-    results = get_results(request, bound_query, orm_models)
 
     if media == "csv":
+        results = get_results(request, bound_query, orm_models)
         buffer = io.StringIO()
         writer = csv.writer(buffer)
 
@@ -248,15 +220,19 @@ def _data_response(request, query, media, meta):
         )
 
         buffer.seek(0)
-        response = http.HttpResponse(buffer, content_type="text")
+        response = HttpResponse(buffer, content_type="text")
         response[
             "Content-Disposition"
         ] = f"attachment; filename={query.model_name}-{timezone.now().isoformat()}.csv"
         return response
     elif media == "json":
+        results = get_results(request, bound_query, orm_models)
         resp = _get_query_data(bound_query) if meta else {}
         resp.update(results)
-        return http.JsonResponse(resp)
+        return JsonResponse(resp)
+    elif media == "query":
+        resp = _get_query_data(bound_query) if meta else {}
+        return JsonResponse(resp)
     else:
         raise http.Http404(f"Bad file format {media} requested")
 
@@ -265,11 +241,12 @@ def _get_from_js_dev_server(request):  # pragma: no cover
     import requests
 
     upstream_url = f"http://127.0.0.1:3000{request.path}"
+    print(f"Proxy request: {upstream_url}")
     method = request.META["REQUEST_METHOD"].lower()
     return getattr(requests, method)(upstream_url, stream=True)
 
 
-@csrf_exempt
+@csrf.csrf_exempt
 def proxy_js_dev_server(request, path):  # pragma: no cover
     """
     Proxy HTTP requests to the frontend dev server in development.
