@@ -1,4 +1,5 @@
 from django.contrib import admin
+from django.contrib.contenttypes.admin import GenericInlineModelAdmin
 
 from . import models
 
@@ -10,10 +11,14 @@ class InlineAdminInline(admin.TabularInline):
     fields = ["name"]
 
 
+class GenericInlineAdminInline(GenericInlineModelAdmin):
+    model = models.GenericInlineAdmin
+
+
 @admin.register(models.InAdmin)
 class InAdmin(admin.ModelAdmin):
     fields = ["name"]
-    inlines = [InlineAdminInline]
+    inlines = [InlineAdminInline, GenericInlineAdminInline]
 
 
 @admin.register(models.Normal)
