@@ -2,10 +2,11 @@ import csv
 import json
 from datetime import datetime
 
-import data_browser.models
 import pytest
 from django.contrib.auth.models import User
 
+import data_browser.models
+
 from . import models
 from .util import update_fe_fixture
 
@@ -54,10 +55,17 @@ def test_query_html(admin_client, snapshot):
         "/data_browser/query/tests.Product/size-0,name+1,size_unit.html?size__lt=2&id__gt=0"
     )
     assert res.status_code == 200
-    context = json.loads(res.context["ctx"])
-    context["config"]["version"] = "redacted"
-    context["initialState"]["version"] = "redacted"
-    snapshot.assert_match(context, "context")
+    config = json.loads(res.context["config"])
+    snapshot.assert_match(config, "config")
+
+
+def test_query_query(admin_client, snapshot):
+    res = admin_client.get(
+        "/data_browser/query/tests.Product/size-0,name+1,size_unit.query?size__lt=2&id__gt=0"
+    )
+    assert res.status_code == 200
+    query = json.loads(res.content.decode("utf-8"))
+    snapshot.assert_match(query, "query")
 
 
 def test_query_html_no_perms(admin_user, admin_client, snapshot):
@@ -65,20 +73,16 @@ def test_query_html_no_perms(admin_user, admin_client, snapshot):
     admin_user.save()
     res = admin_client.get("/data_browser/query//.html?")
     assert res.status_code == 200
-    context = json.loads(res.context["ctx"])
-    context["config"]["version"] = "redacted"
-    context["initialState"]["version"] = "redacted"
-    snapshot.assert_match(context, "context")
+    config = json.loads(res.context["config"])
+    snapshot.assert_match(config, "config")
 
 
 def test_query_ctx(admin_client, snapshot):
     res = admin_client.get("/data_browser/query//.ctx?")
     assert res.status_code == 200
-    context = res.json()
-    context["config"]["version"] = "redacted"
-    context["initialState"]["version"] = "redacted"
-    snapshot.assert_match(context, "context")
-    update_fe_fixture("frontend/src/context_fixture.json", context)
+    config = res.json()
+    snapshot.assert_match(config, "config")
+    update_fe_fixture("frontend/src/context_fixture.json", config)
 
 
 @pytest.mark.usefixtures("products")
@@ -111,14 +115,7 @@ def test_query_json_bad_fields(admin_client):
     ]
 
 
-def test_query_html_bad_model(admin_client):
-    res = admin_client.get(
-        "/data_browser/query/tests.Bob/size-0,name+1,size_unit.html?size__lt=2&id__gt=0"
-    )
-    assert res.status_code == 404
-
-
-def test_query_html_bad_media(admin_client):
+def test_query_bad_media(admin_client):
     res = admin_client.get(
         "/data_browser/query/tests.Product/size-0,name+1,size_unit.bob?size__lt=2&id__gt=0"
     )
@@ -203,7 +200,6 @@ def test_query_json(admin_client, snapshot):
     )
     assert res.status_code == 200
     data = json.loads(res.content.decode("utf-8"))
-    data["version"] = "redacted"
     snapshot.assert_match(data, "data")
 
 
@@ -214,7 +210,6 @@ def test_query_json_pivot(admin_client, snapshot):
     )
     assert res.status_code == 200
     data = json.loads(res.content.decode("utf-8"))
-    data["version"] = "redacted"
     snapshot.assert_match(data, "data")
 
 
@@ -283,6 +278,7 @@ def test_view_json(admin_client):
         ],
         "cols": [{}],
         "body": [[{}, {}]],
+        "length": 2,
     }
 
     view.owner = User.objects.create(is_staff=True)
